==> md5.js-1.0.0.tgz: package/index.js <==
'use strict'
var inherits = require('inherits')
var HashBase = require('hash-base')

function MD5 () {
  HashBase.call(this)

  // state
  this._a = 0x67452301
  this._b = 0xefcdab89
  this._c = 0x98badcfe
  this._d = 0x10325476

  // block data
  this._block = new Buffer(64) // 64 * 8 = 512 bit
  this._blockLength = 0
  this._lengthL = 0
  this._lengthH = 0
}

inherits(MD5, HashBase)

MD5.prototype._update = function (data) {
  // consume data
  var offset = 0
  while (this._blockLength + data.length - offset >= 64) {
    for (var i = this._blockLength; i < 64;) this._block[i++] = data[offset++]
    this._handleBlock()
    this._blockLength = 0
  }

  while (offset < data.length) {
    this._block[this._blockLength++] = data[offset++]
  }

  // update length
  this._lengthL += data.length * 8
  if (this._lengthL > 0xffffffff) {
    this._lengthL -= 0x0100000000
    this._lengthH += 1
    if (this._lengthH > 0xffffffff) this._lengthH = 0
  }
}

MD5.prototype._digest = function () {
  // create padding and handle blocks
  this._block[this._blockLength++] = 0x80
  if (this._blockLength > 56) {
    this._block.fill(0, this._blockLength, 64)
    this._handleBlock()
    this._blockLength = 0
  }

  this._block.fill(0, this._blockLength, 56)
  this._block.writeUInt32LE(this._lengthL, 56)
  this._block.writeUInt32LE(this._lengthH, 60)
  this._handleBlock()

  // produce result
  var buffer = new Buffer(16)
  buffer.writeUInt32LE(this._a, 0)
  buffer.writeUInt32LE(this._b, 4)
  buffer.writeUInt32LE(this._c, 8)
  buffer.writeUInt32LE(this._d, 12)
  return buffer
}

MD5.prototype._handleBlock = function () {
  var m = new Array(16)
  for (var i = 0; i < 16; ++i) m[i] = this._block.readUInt32LE(i * 4)

  var a = this._a
  var b = this._b
  var c = this._c
  var d = this._d

  a = fnF(a, b, c, d, m[0], 0xd76aa478, 7)
  d = fnF(d, a, b, c, m[1], 0xe8c7b756, 12)
  c = fnF(c, d, a, b, m[2], 0x242070db, 17)
  b = fnF(b, c, d, a, m[3], 0xc1bdceee, 22)
  a = fnF(a, b, c, d, m[4], 0xf57c0faf, 7)
  d = fnF(d, a, b, c, m[5], 0x4787c62a, 12)
  c = fnF(c, d, a, b, m[6], 0xa8304613, 17)
  b = fnF(b, c, d, a, m[7], 0xfd469501, 22)
  a = fnF(a, b, c, d, m[8], 0x698098d8, 7)
  d = fnF(d, a, b, c, m[9], 0x8b44f7af, 12)
  c = fnF(c, d, a, b, m[10], 0xffff5bb1, 17)
  b = fnF(b, c, d, a, m[11], 0x895cd7be, 22)
  a = fnF(a, b, c, d, m[12], 0x6b901122, 7)
  d = fnF(d, a, b, c, m[13], 0xfd987193, 12)
  c = fnF(c, d, a, b, m[14], 0xa679438e, 17)
  b = fnF(b, c, d, a, m[15], 0x49b40821, 22)

  a = fnG(a, b, c, d, m[1], 0xf61e2562, 5)
  d = fnG(d, a, b, c, m[6], 0xc040b340, 9)
  c = fnG(c, d, a, b, m[11], 0x265e5a51, 14)
  b = fnG(b, c, d, a, m[0], 0xe9b6c7aa, 20)
  a = fnG(a, b, c, d, m[5], 0xd62f105d, 5)
  d = fnG(d, a, b, c, m[10], 0x02441453, 9)
  c = fnG(c, d, a, b, m[15], 0xd8a1e681, 14)
  b = fnG(b, c, d, a, m[4], 0xe7d3fbc8, 20)
  a = fnG(a, b, c, d, m[9], 0x21e1cde6, 5)
  d = fnG(d, a, b, c, m[14], 0xc33707d6, 9)
  c = fnG(c, d, a, b, m[3], 0xf4d50d87, 14)
  b = fnG(b, c, d, a, m[8], 0x455a14ed, 20)
  a = fnG(a, b, c, d, m[13], 0xa9e3e905, 5)
  d = fnG(d, a, b, c, m[2], 0xfcefa3f8, 9)
  c = fnG(c, d, a, b, m[7], 0x676f02d9, 14)
  b = fnG(b, c, d, a, m[12], 0x8d2a4c8a, 20)

  a = fnH(a, b, c, d, m[5], 0xfffa3942, 4)
  d = fnH(d, a, b, c, m[8], 0x8771f681, 11)
  c = fnH(c, d, a, b, m[11], 0x6d9d6122, 16)
  b = fnH(b, c, d, a, m[14], 0xfde5380c, 23)
  a = fnH(a, b, c, d, m[1], 0xa4beea44, 4)
  d = fnH(d, a, b, c, m[4], 0x4bdecfa9, 11)
  c = fnH(c, d, a, b, m[7], 0xf6bb4b60, 16)
  b = fnH(b, c, d, a, m[10], 0xbebfbc70, 23)
  a = fnH(a, b, c, d, m[13], 0x289b7ec6, 4)
  d = fnH(d, a, b, c, m[0], 0xeaa127fa, 11)
  c = fnH(c, d, a, b, m[3], 0xd4ef3085, 16)
  b = fnH(b, c, d, a, m[6], 0x04881d05, 23)
  a = fnH(a, b, c, d, m[9], 0xd9d4d039, 4)
  d = fnH(d, a, b, c, m[12], 0xe6db99e5, 11)
  c = fnH(c, d, a, b, m[15], 0x1fa27cf8, 16)
  b = fnH(b, c, d, a, m[2], 0xc4ac5665, 23)

  a = fnI(a, b, c, d, m[0], 0xf4292244, 6)
  d = fnI(d, a, b, c, m[7], 0x432aff97, 10)
  c = fnI(c, d, a, b, m[14], 0xab9423a7, 15)
  b = fnI(b, c, d, a, m[5], 0xfc93a039, 21)
  a = fnI(a, b, c, d, m[12], 0x655b59c3, 6)
  d = fnI(d, a, b, c, m[3], 0x8f0ccc92, 10)
  c = fnI(c, d, a, b, m[10], 0xffeff47d, 15)
  b = fnI(b, c, d, a, m[1], 0x85845dd1, 21)
  a = fnI(a, b, c, d, m[8], 0x6fa87e4f, 6)
  d = fnI(d, a, b, c, m[15], 0xfe2ce6e0, 10)
  c = fnI(c, d, a, b, m[6], 0xa3014314, 15)
  b = fnI(b, c, d, a, m[13], 0x4e0811a1, 21)
  a = fnI(a, b, c, d, m[4], 0xf7537e82, 6)
  d = fnI(d, a, b, c, m[11], 0xbd3af235, 10)
  c = fnI(c, d, a, b, m[2], 0x2ad7d2bb, 15)
  b = fnI(b, c, d, a, m[9], 0xeb86d391, 21)

  this._a = (this._a + a) >>> 0
  this._b = (this._b + b) >>> 0
  this._c = (this._c + c) >>> 0
  this._d = (this._d + d) >>> 0
}

function rotl (x, n) {
  return ((x << n) | (x >>> (32 - n))) >>> 0
}

function fnSum (a, f, m, k, s, b) {
  return (rotl(a + (f >>> 0) + m + k, s) + b) >>> 0
}

function fnF (a, b, c, d, m, k, s) {
  return fnSum(a, (b & c) | ((~b) & d), m, k, s, b)
}

function fnG (a, b, c, d, m, k, s) {
  return fnSum(a, (b & d) | (c & (~d)), m, k, s, b)
}

function fnH (a, b, c, d, m, k, s) {
  return fnSum(a, b ^ c ^ d, m, k, s, b)
}

function fnI (a, b, c, d, m, k, s) {
  return fnSum(a, c ^ (b | (~d)), m, k, s, b)
}

module.exports = MD5

==> md5.js-1.2.0.tgz: package/index.js <==
'use strict'
var inherits = require('inherits')
var HashBase = require('hash-base')

function MD5 () {
  HashBase.call(this, 64)

  // state
  this._a = 0x67452301
  this._b = 0xefcdab89
  this._c = 0x98badcfe
  this._d = 0x10325476
}

inherits(MD5, HashBase)

MD5.prototype._update = function () {
  var m = new Array(16)
  for (var i = 0; i < 16; ++i) m[i] = this._block.readUInt32LE(i * 4)

  var a = this._a
  var b = this._b
  var c = this._c
  var d = this._d

  a = fnF(a, b, c, d, m[0], 0xd76aa478, 7)
  d = fnF(d, a, b, c, m[1], 0xe8c7b756, 12)
  c = fnF(c, d, a, b, m[2], 0x242070db, 17)
  b = fnF(b, c, d, a, m[3], 0xc1bdceee, 22)
  a = fnF(a, b, c, d, m[4], 0xf57c0faf, 7)
  d = fnF(d, a, b, c, m[5], 0x4787c62a, 12)
  c = fnF(c, d, a, b, m[6], 0xa8304613, 17)
  b = fnF(b, c, d, a, m[7], 0xfd469501, 22)
  a = fnF(a, b, c, d, m[8], 0x698098d8, 7)
  d = fnF(d, a, b, c, m[9], 0x8b44f7af, 12)
  c = fnF(c, d, a, b, m[10], 0xffff5bb1, 17)
  b = fnF(b, c, d, a, m[11], 0x895cd7be, 22)
  a = fnF(a, b, c, d, m[12], 0x6b901122, 7)
  d = fnF(d, a, b, c, m[13], 0xfd987193, 12)
  c = fnF(c, d, a, b, m[14], 0xa679438e, 17)
  b = fnF(b, c, d, a, m[15], 0x49b40821, 22)

  a = fnG(a, b, c, d, m[1], 0xf61e2562, 5)
  d = fnG(d, a, b, c, m[6], 0xc040b340, 9)
  c = fnG(c, d, a, b, m[11], 0x265e5a51, 14)
  b = fnG(b, c, d, a, m[0], 0xe9b6c7aa, 20)
  a = fnG(a, b, c, d, m[5], 0xd62f105d, 5)
  d = fnG(d, a, b, c, m[10], 0x02441453, 9)
  c = fnG(c, d, a, b, m[15], 0xd8a1e681, 14)
  b = fnG(b, c, d, a, m[4], 0xe7d3fbc8, 20)
  a = fnG(a, b, c, d, m[9], 0x21e1cde6, 5)
  d = fnG(d, a, b, c, m[14], 0xc33707d6, 9)
  c = fnG(c, d, a, b, m[3], 0xf4d50d87, 14)
  b = fnG(b, c, d, a, m[8], 0x455a14ed, 20)
  a = fnG(a, b, c, d, m[13], 0xa9e3e905, 5)
  d = fnG(d, a, b, c, m[2], 0xfcefa3f8, 9)
  c = fnG(c, d, a, b, m[7], 0x676f02d9, 14)
  b = fnG(b, c, d, a, m[12], 0x8d2a4c8a, 20)

  a = fnH(a, b, c, d, m[5], 0xfffa3942, 4)
  d = fnH(d, a, b, c, m[8], 0x8771f681, 11)
  c = fnH(c, d, a, b, m[11], 0x6d9d6122, 16)
  b = fnH(b, c, d, a, m[14], 0xfde5380c, 23)
  a = fnH(a, b, c, d, m[1], 0xa4beea44, 4)
  d = fnH(d, a, b, c, m[4], 0x4bdecfa9, 11)
  c = fnH(c, d, a, b, m[7], 0xf6bb4b60, 16)
  b = fnH(b, c, d, a, m[10], 0xbebfbc70, 23)
  a = fnH(a, b, c, d, m[13], 0x289b7ec6, 4)
  d = fnH(d, a, b, c, m[0], 0xeaa127fa, 11)
  c = fnH(c, d, a, b, m[3], 0xd4ef3085, 16)
  b = fnH(b, c, d, a, m[6], 0x04881d05, 23)
  a = fnH(a, b, c, d, m[9], 0xd9d4d039, 4)
  d = fnH(d, a, b, c, m[12], 0xe6db99e5, 11)
  c = fnH(c, d, a, b, m[15], 0x1fa27cf8, 16)
  b = fnH(b, c, d, a, m[2], 0xc4ac5665, 23)

  a = fnI(a, b, c, d, m[0], 0xf4292244, 6)
  d = fnI(d, a, b, c, m[7], 0x432aff97, 10)
  c = fnI(c, d, a, b, m[14], 0xab9423a7, 15)
  b = fnI(b, c, d, a, m[5], 0xfc93a039, 21)
  a = fnI(a, b, c, d, m[12], 0x655b59c3, 6)
  d = fnI(d, a, b, c, m[3], 0x8f0ccc92, 10)
  c = fnI(c, d, a, b, m[10], 0xffeff47d, 15)
  b = fnI(b, c, d, a, m[1], 0x85845dd1, 21)
  a = fnI(a, b, c, d, m[8], 0x6fa87e4f, 6)
  d = fnI(d, a, b, c, m[15], 0xfe2ce6e0, 10)
  c = fnI(c, d, a, b, m[6], 0xa3014314, 15)
  b = fnI(b, c, d, a, m[13], 0x4e0811a1, 21)
  a = fnI(a, b, c, d, m[4], 0xf7537e82, 6)
  d = fnI(d, a, b, c, m[11], 0xbd3af235, 10)
  c = fnI(c, d, a, b, m[2], 0x2ad7d2bb, 15)
  b = fnI(b, c, d, a, m[9], 0xeb86d391, 21)

  this._a = (this._a + a) >>> 0
  this._b = (this._b + b) >>> 0
  this._c = (this._c + c) >>> 0
  this._d = (this._d + d) >>> 0
}

MD5.prototype._digest = function () {
  // create padding and handle blocks
  this._block[this._blockOffset++] = 0x80
  if (this._blockOffset > 56) {
    this._block.fill(0, this._blockOffset, 64)
    this._update()
    this._blockOffset = 0
  }

  this._block.fill(0, this._blockOffset, 56)
  this._block.writeUInt32LE(this._length[0], 56)
  this._block.writeUInt32LE(this._length[1], 60)
  this._update()

  // produce result
  var buffer = new Buffer(16)
  buffer.writeUInt32LE(this._a, 0)
  buffer.writeUInt32LE(this._b, 4)
  buffer.writeUInt32LE(this._c, 8)
  buffer.writeUInt32LE(this._d, 12)
  return buffer
}

function rotl (x, n) {
  return ((x << n) | (x >>> (32 - n))) >>> 0
}

function fnF (a, b, c, d, m, k, s) {
  return (rotl(a + ((b & c) | ((~b) & d) >>> 0) + m + k, s) + b) >>> 0
}

function fnG (a, b, c, d, m, k, s) {
  return (rotl(a + ((b & d) | (c & (~d)) >>> 0) + m + k, s) + b) >>> 0
}

function fnH (a, b, c, d, m, k, s) {
  return (rotl(a + ((b ^ c ^ d) >>> 0) + m + k, s) + b) >>> 0
}

function fnI (a, b, c, d, m, k, s) {
  return (rotl(a + ((c ^ (b | (~d))) >>> 0) + m + k, s) + b) >>> 0
}

module.exports = MD5
